@@ -2,21 +2,21 @@
 pyart.util.radar_utils
 ======================
 
-======================
 Functions for working radar instances.
+
 .. autosummary::
     :toctree: generated/
+
     is_vpt
     to_vpt
-    compute_azimuthal_average
     join_radar
     join_spectra
     cut_radar
     cut_radar_spectra
     radar_from_spectra
     interpol_spectra
-    find_neighbour_gates
     ma_broadcast_to
+
 """
 
 import copy
@@ -26,18 +26,19 @@ import numpy as np
 from scipy.interpolate import interp1d
 from netCDF4 import date2num
 
+from ..config import get_fillvalue
 from ..core import Radar
-from ..config import get_metadata, get_fillvalue
-from . import compute_directional_stats
-from . import cross_section_rhi, get_target_elevations
+from . import datetime_utils
 
 
 def is_vpt(radar, offset=0.5):
     """
     Determine if a Radar appears to be a vertical pointing scan.
+
     This function only verifies that the object is a vertical pointing scan,
     use the :py:func:`to_vpt` function to convert the radar to a vpt scan
     if this function returns True.
+
     Parameters
     ----------
     radar : Radar
@@ -45,10 +46,12 @@ def is_vpt(radar, offset=0.5):
     offset : float, optional
         Maximum offset of the elevation from 90 degrees to still consider
         to be vertically pointing.
+
     Returns
     -------
     flag : bool
         True if the radar appear to be verticle pointing, False if not.
+
     """
     # check that the elevation is within offset of 90 degrees.
     elev = radar.elevation['data']
@@ -58,8 +61,10 @@ def is_vpt(radar, offset=0.5):
 def to_vpt(radar, single_scan=True):
     """
     Convert an existing Radar object to represent a vertical pointing scan.
+
     This function does not verify that the Radar object contains a vertical
     pointing scan. To perform such a check use :py:func:`is_vpt`.
+
     Parameters
     ----------
     radar : Radar
@@ -70,6 +75,7 @@ def to_vpt(radar, single_scan=True):
         True to convert the volume to a single scan, any azimuth angle data
         is lost. False will convert the scan to contain the same number of
         scans as rays, azimuth angles are retained.
+
     """
     if single_scan:
         nsweeps = 1
@@ -116,145 +122,17 @@ def to_vpt(radar, single_scan=True):
     # radar.scan_rate
 
 
-def compute_azimuthal_average(radar, field_names, angle=None, delta_azi=None,
-                              avg_type='mean', nvalid_min=1):
-    """
-    Computes the azimuthal average
-    Parameters
-    ----------
-    radar : Radar object
-        input radar objects
-    field_names : list of str
-        name of the fields to include in the average
-    angle : float or None
-        The center angle to average. If not set or set to -1 all
-        available azimuth angles will be used
-    delta_azi : float. Dataset keyword
-        The angle span to average. If not set or set to -1 all the
-        available azimuth angles will be used
-    avg_type : str. Dataset keyword
-        Average type. Can be mean or median. Default mean
-    nvalid_min : int. Dataset keyword
-        the minimum number of valid points to consdier the average valid.
-        Default 1
-    Returns
-    -------
-    radar_rhi : Radar object
-        new radar object where azimuths have been averaged
-    """
-    # keep only fields present in radar object
-    field_names_aux = []
-    nfields_available = 0
-    for field_name in field_names:
-        if field_name not in radar.fields:
-            warn('Field name '+field_name+' not available in radar object')
-            continue
-        field_names_aux.append(field_name)
-        nfields_available += 1
-
-    if nfields_available == 0:
-        warn("Fields not available in radar data")
-        return None
-
-    # check input parameters
-    if avg_type not in ('mean', 'median'):
-        warn('Unsuported statistics '+avg_type)
-        return None
-
-    if delta_azi == -1:
-        delta_azi = None
-    if angle == -1:
-        angle = None
-
-    radar_aux = copy.deepcopy(radar)
-    # transform radar into ppi over the required elevation
-    if radar_aux.scan_type == 'rhi':
-        target_elevations, el_tol = get_target_elevations(radar_aux)
-        radar_ppi = cross_section_rhi(
-            radar_aux, target_elevations, el_tol=el_tol)
-    elif radar_aux.scan_type == 'ppi':
-        radar_ppi = radar_aux
-    else:
-        warn('Error: unsupported scan type.')
-        return None
-
-    # range, metadata, radar position are the same as the original
-    # time
-    radar_rhi = copy.deepcopy(radar)
-    radar_rhi.fields = dict()
-    radar_rhi.scan_type = 'rhi'
-    radar_rhi.sweep_number['data'] = np.array([0])
-    radar_rhi.sweep_mode['data'] = np.array(['rhi'])
-    radar_rhi.fixed_angle['data'] = np.array([0])
-    radar_rhi.sweep_start_ray_index['data'] = np.array([0])
-    radar_rhi.sweep_end_ray_index['data'] = np.array([radar_ppi.nsweeps-1])
-    radar_rhi.rays_per_sweep['data'] = np.array([radar_ppi.nsweeps])
-    radar_rhi.azimuth['data'] = np.ones(radar_ppi.nsweeps)
-    radar_rhi.elevation['data'] = radar_ppi.fixed_angle['data']
-    radar_rhi.time['data'] = np.zeros(radar_ppi.nsweeps)
-    radar_rhi.nrays = radar_ppi.fixed_angle['data'].size
-    radar_rhi.nsweeps = 1
-    radar_rhi.rays_are_indexed = None
-    radar_rhi.ray_angle_res = None
-
-    # average radar data
-    if angle is None:
-        fixed_angle = np.zeros(radar_ppi.nsweeps)
-
-    fields_dict = dict()
-    for field_name in field_names_aux:
-        fields_dict.update(
-            {field_name: get_metadata(field_name)})
-        fields_dict[field_name]['data'] = np.ma.masked_all(
-            (radar_ppi.nsweeps, radar_ppi.ngates))
-
-    for sweep in range(radar_ppi.nsweeps):
-        radar_aux = copy.deepcopy(radar_ppi)
-        radar_aux = radar_aux.extract_sweeps([sweep])
-
-        # find neighbouring gates to be selected
-        inds_ray, inds_rng = find_neighbour_gates(
-            radar_aux, angle, None, delta_azi=delta_azi, delta_rng=None)
-
-        if angle is None:
-            fixed_angle[sweep] = np.median(
-                radar_aux.azimuth['data'][inds_ray])
-
-        # get time as the mean of the time of the selected rays
-        radar_rhi.time['data'][sweep] = np.mean(
-            radar_aux.time['data'][inds_ray])
-
-        # keep only data we are interested in
-        for field_name in field_names_aux:
-            field_aux = radar_aux.fields[field_name]['data'][:, inds_rng]
-            field_aux = field_aux[inds_ray, :]
-
-            vals, _ = compute_directional_stats(
-                field_aux, avg_type=avg_type, nvalid_min=nvalid_min, axis=0)
-
-            fields_dict[field_name]['data'][sweep, :] = vals
-
-    if angle is None:
-        radar_rhi.fixed_angle['data'] = np.array([np.mean(fixed_angle)])
-    else:
-        radar_rhi.fixed_angle['data'] = np.array([angle])
-    radar_rhi.azimuth['data'] *= radar_rhi.fixed_angle['data'][0]
-
-    for field_name in field_names_aux:
-        radar_rhi.add_field(field_name, fields_dict[field_name])
-
-    return radar_rhi
-
-
 def join_radar(radar1, radar2):
     """
     Combine two radar instances into one.
+
     Parameters
     ----------
     radar1 : Radar
         Radar object.
     radar2 : Radar
         Radar object.
+
     """
     # must have same gate spacing
     new_radar = copy.deepcopy(radar1)
@@ -385,12 +263,14 @@ def join_radar(radar1, radar2):
 def join_spectra(spectra1, spectra2):
     """
     Combine two spectra instances into one.
+
     Parameters
     ----------
     spectra1 : spectra
         spectra object.
     spectra2 : spectra
         spectra object.
+
     """
     # must have same gate spacing
     new_spectra = copy.deepcopy(spectra1)
@@ -531,12 +411,9 @@ def join_spectra(spectra1, spectra2):
         if (lat1 != lat2) or (lon1 != lon2) or (alt1 != alt2):
             ones1 = np.ones(len(spectra1.time['data']), dtype='float32')
             ones2 = np.ones(len(spectra2.time['data']), dtype='float32')
-            new_spectra.latitude['data'] = np.append(
-                ones1 * lat1, ones2 * lat2)
-            new_spectra.longitude['data'] = np.append(
-                ones1 * lon1, ones2 * lon2)
-            new_spectra.latitude['data'] = np.append(
-                ones1 * alt1, ones2 * alt2)
+            new_spectra.latitude['data'] = np.append(ones1 * lat1, ones2 * lat2)
+            new_spectra.longitude['data'] = np.append(ones1 * lon1, ones2 * lon2)
+            new_spectra.latitude['data'] = np.append(ones1 * alt1, ones2 * alt2)
         else:
             new_spectra.latitude['data'] = spectra1.latitude['data']
             new_spectra.longitude['data'] = spectra1.longitude['data']
@@ -557,6 +434,7 @@ def cut_radar(radar, field_names, rng_min=None, rng_max=None, ele_min=None,
               ele_max=None, azi_min=None, azi_max=None):
     """
     Cuts the radar object into new dimensions
+
     Parameters
     ----------
     radar : radar object
@@ -569,10 +447,12 @@ def cut_radar(radar, field_names, rng_min=None, rng_max=None, ele_min=None,
     ele_min, ele_max, azi_min, azi_max : float or None
         The limits of the grid [deg]. If None the limits will be the limits
         of the radar volume
+
     Returns
     -------
     radar : radar object
         The radar object containing only the desired data
+
     """
     radar_aux = copy.deepcopy(radar)
 
@@ -586,8 +466,7 @@ def cut_radar(radar, field_names, rng_min=None, rng_max=None, ele_min=None,
         rng_max = np.max(radar_aux.range['data'])
 
     ind_rng = np.where(np.logical_and(
-        radar_aux.range['data'] >= rng_min,
-        radar_aux.range['data'] <= rng_max))[0]
+        radar_aux.range['data'] >= rng_min, radar_aux.range['data'] <= rng_max))[0]
 
     if ind_rng.size == 0:
         warn('No range bins between '+str(rng_min)+' and '+str(rng_max)+' m')
@@ -671,29 +550,11 @@ def cut_radar(radar, field_names, rng_min=None, rng_max=None, ele_min=None,
     sweep_end_inds = copy.deepcopy(radar_aux.sweep_end_ray_index['data'])
 
     nrays = 0
-    ind_rays_aux = []
     for j in range(radar_aux.nsweeps):
-        # get ray indices for this sweep
-        ind_rays_sweep = ind_rays[np.logical_and(
-            ind_rays >= sweep_start_inds[j], ind_rays <= sweep_end_inds[j])]
-        # order rays
-        if radar_aux.scan_type == 'ppi':
-            ind = np.argsort(radar_aux.azimuth['data'][ind_rays_sweep])
-            ind_rays_sweep = ind_rays_sweep[ind]
-            # avoid large gaps in data
-            azimuths = radar_aux.azimuth['data'][ind_rays_sweep]
-            azi_steps = azimuths[1:]-azimuths[:-1]
-            ind_gap = np.where(azi_steps > 2*np.median(azi_steps))[0]
-            if ind_gap.size > 0:
-                ind_rays_sweep = np.append(
-                    ind_rays_sweep[ind_gap[0]+1:],
-                    ind_rays_sweep[:ind_gap[0]+1])
-            ind_rays_aux.extend(ind_rays_sweep)
-        else:
-            ind = np.argsort(radar_aux.elevation['data'][ind_rays_sweep])
-            ind_rays_aux.extend(ind_rays_sweep[ind])
-
-        rays_in_sweep = ind_rays_sweep.size
+        # get azimuth indices for this elevation
+        rays_in_sweep = np.size(
+            ind_rays[np.logical_and(ind_rays >= sweep_start_inds[j],
+                                    ind_rays <= sweep_end_inds[j])])
         radar_aux.rays_per_sweep['data'][j] = rays_in_sweep
         if j == 0:
             radar_aux.sweep_start_ray_index['data'][j] = 0
@@ -704,8 +565,6 @@ def cut_radar(radar, field_names, rng_min=None, rng_max=None, ele_min=None,
             radar_aux.sweep_start_ray_index['data'][j]+rays_in_sweep-1)
         nrays += rays_in_sweep
 
-    ind_rays = np.array(ind_rays_aux)
-
     # Update metadata
     radar_aux.range['data'] = radar_aux.range['data'][ind_rng]
     radar_aux.time['data'] = radar_aux.time['data'][ind_rays]
@@ -755,6 +614,7 @@ def cut_radar_spectra(radar, field_names, rng_min=None, rng_max=None,
                       ele_min=None, ele_max=None, azi_min=None, azi_max=None):
     """
     Cuts the radar spectra object into new dimensions
+
     Parameters
     ----------
     radar : radar object
@@ -767,10 +627,12 @@ def cut_radar_spectra(radar, field_names, rng_min=None, rng_max=None,
     ele_min, ele_max, azi_min, azi_max : float or None
         The limits of the grid [deg]. If None the limits will be the limits
         of the radar volume
+
     Returns
     -------
     radar : radar object
         The radar object containing only the desired data
+
     """
     radar_aux = copy.deepcopy(radar)
 
@@ -784,8 +646,7 @@ def cut_radar_spectra(radar, field_names, rng_min=None, rng_max=None,
         rng_max = np.max(radar_aux.range['data'])
 
     ind_rng = np.where(np.logical_and(
-        radar_aux.range['data'] >= rng_min,
-        radar_aux.range['data'] <= rng_max))[0]
+        radar_aux.range['data'] >= rng_min, radar_aux.range['data'] <= rng_max))[0]
 
     if ind_rng.size == 0:
         warn('No range bins between '+str(rng_min)+' and '+str(rng_max)+' m')
@@ -937,14 +798,17 @@ def cut_radar_spectra(radar, field_names, rng_min=None, rng_max=None,
 def radar_from_spectra(psr):
     """
     obtain a Radar object from a RadarSpectra object
+
     Parameters
     ----------
     psr : RadarSpectra object
         The reference object
+
     Returns
     -------
     radar : radar object
         The new radar object
+
     """
     return Radar(
         psr.time, psr.range, dict(), psr.metadata, psr.scan_type,
@@ -960,14 +824,17 @@ def radar_from_spectra(psr):
 def interpol_spectra(psr, kind='linear', fill_value=0.):
     """
     Interpolates the spectra so that it has a uniform grid
+
     Parameters
     ----------
     psr : RadarSpectra object
         The original spectra
+
     Returns
     -------
     psr_interp : RadarSpectra object
         The interpolated spectra
+
     """
     if psr.Doppler_velocity is not None:
         # check if all rays have the same Doppler velocity field
@@ -1038,63 +905,21 @@ def interpol_spectra(psr, kind='linear', fill_value=0.):
     return psr_interp
 
 
-def find_neighbour_gates(radar, azi, rng, delta_azi=None, delta_rng=None):
-    """
-    Find the neighbouring gates within +-delta_azi and +-delta_rng
-    Parameters
-    ----------
-    radar : radar object
-        the radar object
-    azi, rng : float
-        The azimuth [deg] and range [m] of the central gate
-    delta_azi, delta_rng : float
-        The extend where to look for
-    Returns
-    -------
-    inds_ray_aux, ind_rng_aux : int
-        The indices (ray, rng) of the neighbouring gates
-    """
-    # find gates close to lat lon point
-    if delta_azi is None:
-        inds_ray = np.ma.arange(radar.azimuth['data'].size)
-    else:
-        azi_max = azi+delta_azi
-        azi_min = azi-delta_azi
-        if azi_max > 360.:
-            azi_max -= 360.
-        if azi_min < 0.:
-            azi_min += 360.
-        if azi_max > azi_min:
-            inds_ray = np.where(np.logical_and(
-                radar.azimuth['data'] < azi_max,
-                radar.azimuth['data'] > azi_min))[0]
-        else:
-            inds_ray = np.where(np.logical_or(
-                radar.azimuth['data'] > azi_min,
-                radar.azimuth['data'] < azi_max))[0]
-    if delta_rng is None:
-        inds_rng = np.ma.arange(radar.range['data'].size)
-    else:
-        inds_rng = np.where(np.logical_and(
-            radar.range['data'] < rng+delta_rng,
-            radar.range['data'] > rng-delta_rng))[0]
-
-    return inds_ray, inds_rng
-
-
 def ma_broadcast_to(array, tup):
     """
-    Is used to guarantee that a masked array can be broadcasted without
-    loosing the mask
+    Is used to guarantee that a masked array can be broadcasted without loosing the mask
+
     Parameters
     ----------
     array : Numpy masked array or normal array
     tup : shape as tuple
+
     Returns
     -------
     broadcasted_array
         The broadcasted numpy array including its mask if available
         otherwise only the broadcasted array is returned
+
     """
     broadcasted_array = np.broadcast_to(array, tup)
 
@@ -1102,8 +927,6 @@ def ma_broadcast_to(array, tup):
         initial_mask = np.ma.getmask(array)
         initial_fill_value = array.fill_value
         broadcasted_mask = np.broadcast_to(initial_mask, tup)
-        return np.ma.array(
-            broadcasted_array, mask=broadcasted_mask,
-            fill_value=initial_fill_value)
+        return np.ma.array(broadcasted_array, mask=broadcasted_mask, fill_value=initial_fill_value)
 
     return broadcasted_array
